mix kyopuro.new (Kyopuro v0.3.0) View Source
Once you have logged in, you can specify a contest to generate modules and tests.
ログインが完了したらコンテストを指定してモジュールとテストを生成することができます。
$ mix kyopuro.new ${contest_name}
If you want to generate abc100 modules and tests, here's how it looks like.
abc100のモジュールとテストを生成する場合は以下のようになります。
$ mix kyopuro.new abc100
In this case, the modules and tests will be generated as follows (if you run it in a hoge project)
この場合モジュールとテストは以下のように生成されます。(hogeプロジェクトで実行した場合)
┬ lib ─ hoge ─ abc100 ─ ┬ a.ex
│ ├ b.ex
│ ├ c.ex
│ └ d.ex
│
└ test ─ hoge_test ─ abc100 ┬ a_test.exs
├ b_test.exs
├ c_test.exs
└ d_test.exs
Link to this section Summary
Functions
Callback implementation for Mix.Task.run/1.
Link to this section Functions
Callback implementation for Mix.Task.run/1.