mix kyopuro.submit (Kyopuro v0.3.0) View Source
You can submit a contest name or the name of the contest and task.
コンテスト名もしくはコンテスト名とタスク名を指定して提出することができます。
$ mix kyopuro.submit ${contest_name} or $ mix kyopuro.submit ${contest_name} ${module_file_name}
If you want to generate abc100 modules and tests, this is how it looks like.
abc100の提出をする場合は以下のようになります。
$ mix kyopuro.submit abc100 $ mix kyopuro.submit abc100 a
You can give multiple task names.
タスク名は複数与えることが可能です。
$ mix kyopuro.submit abc100 a b c d
Link to this section Summary
Functions
Callback implementation for Mix.Task.run/1.
Link to this section Functions
Callback implementation for Mix.Task.run/1.